q1ss.ap.explicit
================

.. automodule:: q1ss.ap.explicit

ExplicitAP
----------

.. autoclass:: q1ss.ap.explicit.ExplicitAP
    :show-inheritance:
    :members:
    :special-members: __new__, __getitem__
